.. _rdflib.util: Utilities

=========
Utilities
=========

.. currentmodule:: rdflib.util

Miscellaneous utilities
-----------------------

.. autofunction:: rdflib.util.list2set
.. autofunction:: rdflib.util.first
.. autofunction:: rdflib.util.uniq
.. autofunction:: rdflib.util.more_than

Term characterisation and generation
-------------------------------------

.. autofunction:: rdflib.util.to_term
.. autofunction:: rdflib.util.from_n3


Statement and component type checkers
-------------------------------------

.. autofunction:: rdflib.util.check_context
.. autofunction:: rdflib.util.check_subject
.. autofunction:: rdflib.util.check_predicate
.. autofunction:: rdflib.util.check_object
.. autofunction:: rdflib.util.check_statement
.. autofunction:: rdflib.util.check_pattern

Date/time utilities
-------------------

.. autofunction:: rdflib.util.date_time
.. autofunction:: rdflib.util.parse_date_time
